@@ -9,11 +9,12 @@ import (
 	"strings"
 
 	"github.com/armosec/k8s-interface/workloadinterface"
+	"github.com/dwertent/go-logger/helpers"
 
-	"github.com/armosec/kubescape/v2/core/cautils/logger"
-	"github.com/armosec/kubescape/v2/core/cautils/logger/helpers"
 	"github.com/armosec/opa-utils/objectsenvelopes"
 	"github.com/armosec/opa-utils/objectsenvelopes/localworkload"
+	logger "github.com/dwertent/go-logger"
+
 	"gopkg.in/yaml.v2"
 )
 
