@@ -10,9 +10,9 @@ import (
 	"time"
 
 	"github.com/armosec/armoapi-go/armotypes"
-	"github.com/armosec/kubescape/v2/core/cautils/logger"
-	"github.com/armosec/kubescape/v2/core/cautils/logger/helpers"
 	"github.com/armosec/opa-utils/reporthandling"
+	logger "github.com/dwertent/go-logger"
+	"github.com/dwertent/go-logger/helpers"
 )
 
 // =======================================================================================================================
@@ -23,19 +23,19 @@ var (
 	// ATTENTION!!!
 	// Changes in this URLs variable names, or in the usage is affecting the build process! BE CAREFUL
 	armoERURL   = "report.armo.cloud"
-	armoBEURL   = "api.armo.cloud"
-	armoFEURL   = "portal.armo.cloud"
-	armoAUTHURL = "auth.armo.cloud"
+	armoBEURL   = "api.armosec.io"
+	armoFEURL   = "cloud.armosec.io"
+	armoAUTHURL = "auth.armosec.io"
 
 	armoStageERURL   = "report-ks.eustage2.cyberarmorsoft.com"
-	armoStageBEURL   = "api-stage.armo.cloud"
-	armoStageFEURL   = "armoui.eustage2.cyberarmorsoft.com"
-	armoStageAUTHURL = "eggauth.eustage2.cyberarmorsoft.com"
+	armoStageBEURL   = "api-stage.armosec.io"
+	armoStageFEURL   = "armoui-stage.armosec.io"
+	armoStageAUTHURL = "eggauth-stage.armosec.io"
 
 	armoDevERURL   = "report.eudev3.cyberarmorsoft.com"
-	armoDevBEURL   = "api-dev.armo.cloud"
+	armoDevBEURL   = "api-dev.armosec.io"
 	armoDevFEURL   = "cloud-dev.armosec.io"
-	armoDevAUTHURL = "eggauth.eudev3.cyberarmorsoft.com"
+	armoDevAUTHURL = "eggauth-dev.armosec.io"
 )
 
 // Armo API for downloading policies
