@@ -4,8 +4,8 @@ import (
 	"os"
 
 	"github.com/armosec/kubescape/v2/core/cautils/getter"
-	"github.com/armosec/kubescape/v2/core/cautils/logger"
-	"github.com/armosec/kubescape/v2/core/cautils/logger/zaplogger"
+	logger "github.com/dwertent/go-logger"
+	"github.com/dwertent/go-logger/zaplogger"
 )
 
 func initialize() error {
