@@ -2,7 +2,7 @@ package main
 
 import (
 	"github.com/armosec/kubescape/v2/cmd"
-	"github.com/armosec/kubescape/v2/core/cautils/logger"
+	logger "github.com/dwertent/go-logger"
 )
 
 func main() {
